from .client import (
    EmergentDB,
    EmergentDBError,
    InsertResult,
    BatchInsertResult,
    SearchResult,
    SearchResponse,
    DeleteResult,
)

__all__ = [
    "EmergentDB",
    "EmergentDBError",
    "InsertResult",
    "BatchInsertResult",
    "SearchResult",
    "SearchResponse",
    "DeleteResult",
]
__version__ = "0.0.11"
